@@ -9,6 +9,7 @@ import subprocess
 import click
 from click import echo
 from emoji import emojize
+from lia.check_git.verify_branch import verify_branch
 
 
 @click.group()
@@ -41,6 +42,7 @@ def heal(packagename: str, t: str) -> None:  # pragma: no cover
     :doc-author: Julian M. Kleber
     """
     say_message()
+    verify_branch()
     assert t in ["y", "n"], "Plase specify -t as y/n"
     assert os.path.isdir(packagename)
     if not packagename.endswith("/"):
@@ -87,6 +89,7 @@ def deploy(t: str) -> None:
     :author: Julian M. Kleber
     """
     say_message()
+    verify_branch()
     if t == "y":
         out = subprocess.run(
             ["python -m pytest tests/"], shell=True, check=True, capture_output=True
