@@ -7,10 +7,9 @@ pyproject.toml or setup.py
 """
 
 
-def speak_veritas() -> None:
+def speak_veritas():
     """
     With this function, lia asks you about the details
     of your package.
 
     """
-    pass
